@@ -189,20 +189,20 @@ pub mod macros {
             vec2
         }};
     }
-    /// vec_parse!() can be used to
+    /// vec_element_parse!() can be used to
     /// parse vec item to f64,
     /// type can be Vec\<i32\> Vec\<i64\> Vec\<i128\> Vec\<f32\> Vec\<f64\>,
     /// return Vec\<f64\>
     /// ```rust
-    ///let v1 = vec_parse!(vec!["15.", "2.9"]);
-    ///let v2 = vec_parse!(vec!["15", "2"]);
-    ///let v3 = vec_parse!(vec![".15", ".2"]);
+    ///let v1 = vec_element_parse!(vec!["15.", "2.9"]);
+    ///let v2 = vec_element_parse!(vec!["15", "2"]);
+    ///let v3 = vec_element_parse!(vec![".15", ".2"]);
     ///assert_eq!(vec![15.0, 2.9], v1);
     ///assert_eq!(vec![15.0, 2.0], v2);
     ///assert_eq!(vec![0.15, 0.2], v3);
     /// ```
     #[macro_export]
-    macro_rules! vec_parse {
+    macro_rules! vec_element_parse {
         ($vec:expr) => {{
             let mut v2: Vec<f64> = Vec::new();
             if $vec.len() > 0 {
